==> lifeograph_0.7.3.orig.tar.gz: lifeograph-0.7.3/src/widget_entrylist.hpp <==
/***********************************************************************************

	Copyright (C) 2007-2010 Ahmet Öztürk (aoz_2@yahoo.com)

	This file is part of Lifeograph.

	Lifeograph is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.

	Lifeograph is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with Lifeograph.  If not, see <http://www.gnu.org/licenses/>.

***********************************************************************************/


#ifndef LIFEOGRAPH_WIDGET_ENTRYLIST_HEADER
#define LIFEOGRAPH_WIDGET_ENTRYLIST_HEADER


#include <gtkmm.h>

#include "diarydata.hpp"
#include "entry.hpp"
#include "views.hpp"


namespace LIFEO
{

class WidgetEntryList : public Gtk::TreeView
{
	public:
			typedef sigc::signal< void, Tag* > Signal_void_Tag;
										WidgetEntryList( BaseObjectType*,
														 const Glib::RefPtr<Gtk::Builder>& );
										~WidgetEntryList( void );

			void						present_row( const Gtk::TreePath& );
			void						expand_element( const DiaryElement* );
			void						set_sorting_criteria( void );
			void						handle_sorting_criteria_changed( SortingCriteria );

			// SORTING FUNCTIONS
			int							sort_by_date( const Gtk::TreeModel::iterator&,
													  const Gtk::TreeModel::iterator& );
			int							sort_by_size( const Gtk::TreeModel::iterator&,
													  const Gtk::TreeModel::iterator& );

			Glib::RefPtr< Gtk::TreeStore >
										m_treestore_entries;
			Glib::RefPtr< Gtk::TreeModelSort >
										m_treemodelsort_entries;

	protected:
			//Gtk::Menu					*m_menu;

			void						on_selection_changed( void );
			bool						on_button_press_event( GdkEventButton* );

			//DiaryEntryView*				get_treerow_ptr_entry( const Gtk::TreeRow& );
};


} // end of namespace LIFEO

#endif

==> lifeograph_0.7.4.orig.tar.gz: lifeograph-0.7.4/src/widget_entrylist.hpp <==
/***********************************************************************************

	Copyright (C) 2007-2011 Ahmet Öztürk (aoz_2@yahoo.com)

	This file is part of Lifeograph.

	Lifeograph is free software: you can redistribute it and/or modify
	it under the terms of the GNU General Public License as published by
	the Free Software Foundation, either version 3 of the License, or
	(at your option) any later version.

	Lifeograph is distributed in the hope that it will be useful,
	but WITHOUT ANY WARRANTY; without even the implied warranty of
	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
	GNU General Public License for more details.

	You should have received a copy of the GNU General Public License
	along with Lifeograph.  If not, see <http://www.gnu.org/licenses/>.

***********************************************************************************/


#ifndef LIFEOGRAPH_WIDGET_ENTRYLIST_HEADER
#define LIFEOGRAPH_WIDGET_ENTRYLIST_HEADER


#include <gtkmm.h>

#include "diarydata.hpp"
#include "entry.hpp"
#include "views.hpp"


namespace LIFEO
{

class WidgetEntryList : public Gtk::TreeView
{
	public:
			typedef sigc::signal< void, Tag* > Signal_void_Tag;
										WidgetEntryList( BaseObjectType*,
														 const Glib::RefPtr<Gtk::Builder>& );
										~WidgetEntryList( void );

			void						present_element( const DiaryElement* );
			void						expand_element( const DiaryElement* );
			void						set_sorting_criteria( void );
			void						handle_sorting_criteria_changed( SortingCriteria );

			Gtk::TreePath				find_element( const DiaryElement* ) const;

			DiaryElement*				get_dragged_elem( void )
			{ return m_element_dragged; }

			// SORTING FUNCTIONS
			int							sort_by_date( const Gtk::TreeModel::iterator&,
													  const Gtk::TreeModel::iterator& );
			int							sort_by_size( const Gtk::TreeModel::iterator&,
													  const Gtk::TreeModel::iterator& );

			Glib::RefPtr< Gtk::TreeStore >
										m_treestore_entries;
			Glib::RefPtr< Gtk::TreeModelSort >
										m_treemodelsort_entries;

	protected:
			//Gtk::Menu					*m_menu;
			bool						m_flag_dragging;
			DiaryElement				*m_element_dragged;
			DiaryElement				*m_element_drop_target;

//			void						on_selection_changed( void );

			bool						on_button_press_event( GdkEventButton* );
			bool						on_button_release_event( GdkEventButton* );
			void						on_drag_begin( const Glib::RefPtr< Gdk::DragContext >& );
			void						on_drag_data_get(
												const Glib::RefPtr< Gdk::DragContext >&,
												Gtk::SelectionData&, guint, guint );
			bool						on_drag_motion( const Glib::RefPtr< Gdk::DragContext >&,
														int, int, guint );
			bool						on_drag_drop( const Glib::RefPtr< Gdk::DragContext >&,
													  int x, int y, guint time );
			//void						on_drag_data_received(
												//const Glib::RefPtr< Gdk::DragContext >&,
												//int, int, const Gtk::SelectionData&,
												//guint, guint );

			//DiaryEntryView*				get_treerow_ptr_entry( const Gtk::TreeRow& );
};


} // end of namespace LIFEO

#endif
